==> basic-1.0.3-sources.jar: net/oschina/suyeer/basic/bean/BHttpResContent.java <==
package net.oschina.suyeer.basic.bean;

import net.oschina.suyeer.basic.util.BJsonUtil;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.io.Serializable;

/**
 * Created by jun on 2017/2/16.
 */
public class BHttpResContent<T> implements Serializable {
    private static final long serialVersionUID = -5764986016352461610L;
    private Integer code;
    private String message;
    private T result;
    private transient String reqUrl;
    private transient String reqParams;
    private transient String sessionInfo;
    private transient HttpSession httpSession;

    public BHttpResContent() {
        this.code = Integer.valueOf(200);
        this.message = "";
        this.reqUrl = "";
        this.reqParams = "";
    }

    public BHttpResContent(HttpServletRequest request) {
        if (request != null) {
            this.reqUrl = request.getRequestURI();
            this.reqParams = BJsonUtil.toJsonString(request.getParameterMap());
            this.httpSession = request.getSession();
            if (this.httpSession != null) {
                this.sessionInfo = String.format("{SessionId=%s}", new Object[]{this.httpSession.getId()});
            }
        }

    }

    public Integer getCode() {
        return this.code;
    }

    public void setCode(Integer code) {
        this.code = code;
    }

    public String getMessage() {
        return this.message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public T getResult() {
        return this.result;
    }

    public void setResult(T result) {
        this.result = result;
    }

    public void fillData(Integer code, String message, T result) {
        this.code = code;
        this.message = message;
        this.result = result;
    }

    public String getReqUrl() {
        return this.reqUrl;
    }

    public String getReqParams() {
        return this.reqParams;
    }

    public String getSessionInfo() {
        return this.sessionInfo;
    }

    public HttpSession getHttpSession() {
        return this.httpSession;
    }
}

==> basic-1.0.7-sources.jar: net/oschina/suyeer/basic/bean/BHttpResContent.java <==
package net.oschina.suyeer.basic.bean;

import net.oschina.suyeer.basic.util.BJsonUtil;
import net.oschina.suyeer.basic.util.BasicUtil;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.io.Serializable;

/**
 * Created by jun on 2017/2/16.
 */
public class BHttpResContent<T> implements Serializable {
    private static final long serialVersionUID = -5764986016352461610L;
    private Integer code;
    private String message;
    private T result;
    private transient String userIp;
    private transient String reqUrl;
    private transient String reqParams;
    private transient String sessionId;
    private transient HttpSession httpSession;

    public BHttpResContent() {
        this.code = Integer.valueOf(200);
        this.message = "";
        this.reqUrl = "";
        this.reqParams = "";
        this.userIp = "";
    }

    public BHttpResContent(HttpServletRequest request) {
        if (request != null) {
            this.reqUrl = request.getRequestURI();
            this.reqParams = BJsonUtil.toJsonString(request.getParameterMap());
            this.httpSession = request.getSession();
            this.userIp = BasicUtil.getUserIp(request);
            if (this.httpSession != null) {
                this.sessionId = this.httpSession.getId();
            }
        }

    }

    public Integer getCode() {
        return this.code;
    }

    public void setCode(Integer code) {
        this.code = code;
    }

    public String getMessage() {
        return this.message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public T getResult() {
        return this.result;
    }

    public void setResult(T result) {
        this.result = result;
    }

    public void fillData(Integer code, String message, T result) {
        this.code = code;
        this.message = message;
        this.result = result;
    }

    public String getReqUrl() {
        return this.reqUrl;
    }

    public String getReqParams() {
        return this.reqParams;
    }

    public String getSessionId() {
        return this.sessionId;
    }

    public HttpSession getHttpSession() {
        return this.httpSession;
    }
}
